==> bitcoin_0.16.2~dfsg.orig.tar.gz: bitcoin-0.16.2/src/qt/locale/bitcoin_sn.ts <==
<TS language="sn" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Gadzira Kero Itsva</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Itsva</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopera</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>Vhara</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Dzima</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Makero ekutumira</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Makero ekutambira</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>Kopera Kero</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Gadzirisa</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Zita</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Kero</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(hapana zita)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    </context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>Banned Until</source>
        <translation>Wakavharirwa Kusvika</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>E&amp;xit</source>
        <translation>Buda</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Vhara Application</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;Kuma %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Taridza ruzivo rwekuma %1</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Taridza ruzivo rwe Qt</translation>
    </message>
    <message>
        <source>&amp;Sending addresses...</source>
        <translation>&amp;Makero ekutumira nawo</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses...</source>
        <translation>&amp;Makero ekutambira nawo</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Vhura &amp;URI</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation>Bitcoin</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Chikwama</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Tumira</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Tambira</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Taridza/Usataridza</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Faira</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Rubatsiro</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 kumashure</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Hokoyo</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Ruzivo</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount</source>
        <translation>Marii </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Zuva</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(hapana zita)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Bitcoin</source>
        <translation>Bitcoin</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Marii </translation>
    </message>
    <message>
        <source>Enter a Bitcoin address (e.g. %1)</source>
        <translation>Nyora kero ye Bitcoin (sekuti %1)</translation>
    </message>
    <message>
        <source>%1 d</source>
        <translation>%1 d</translation>
    </message>
    <message>
        <source>%1 h</source>
        <translation>%1 h</translation>
    </message>
    <message>
        <source>%1 m</source>
        <translation>%1 m</translation>
    </message>
    <message>
        <source>%1 s</source>
        <translation>%1 s</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Hapana</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Hapana </translation>
    </message>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>Hapana </translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>Kero</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Marii </translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Zita</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Zuva</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Zita</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(hapana zita)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(hapana zita)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>Zuva</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Marii </translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Zuva</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Zita</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(hapana zita)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Date</source>
        <translation>Zuva</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Zita</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Kero</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Information</source>
        <translation>Ruzivo</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Hokoyo</translation>
    </message>
    </context>
</TS>

==> bitcoin-0.19.1.tar.gz: bitcoin-0.19.1/src/qt/locale/bitcoin_sn.ts <==
<TS language="sn" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Gadzira Kero Itsva</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Itsva</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopera</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>Vhara</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Dzima</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Makero ekutumira</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Makero ekutambira</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>Kopera Kero</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Gadzirisa</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Zita</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Kero</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(hapana zita)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    </context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>Banned Until</source>
        <translation>Wakavharirwa Kusvika</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>E&amp;xit</source>
        <translation>Buda</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Vhara Application</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;Kuma %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Taridza ruzivo rwekuma %1</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Taridza ruzivo rwe Qt</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Vhura &amp;URI</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Tumira</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Tambira</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Taridza/Usataridza</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Faira</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Rubatsiro</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 kumashure</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Hokoyo</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Ruzivo</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount</source>
        <translation>Marii</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Zuva</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(hapana zita)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Bitcoin</source>
        <translation>Bitcoin</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Marii</translation>
    </message>
    <message>
        <source>Enter a Bitcoin address (e.g. %1)</source>
        <translation>Nyora kero ye Bitcoin (sekuti %1)</translation>
    </message>
    <message>
        <source>%1 d</source>
        <translation>%1 d</translation>
    </message>
    <message>
        <source>%1 h</source>
        <translation>%1 h</translation>
    </message>
    <message>
        <source>%1 m</source>
        <translation>%1 m</translation>
    </message>
    <message>
        <source>%1 s</source>
        <translation>%1 s</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Hapana</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Hapana</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>Hapana</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>Kero</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Marii</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Zita</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Chikwama</translation>
    </message>
</context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Zuva</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Zita</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(hapana zita)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(hapana zita)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>Zuva</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Marii</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Zuva</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Zita</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(hapana zita)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Date</source>
        <translation>Zuva</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Zita</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Kero</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>
